'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.messages = exports.ruleName = undefined;

var _stylelint = require('stylelint');

var _utils = require('../../utils');

var ruleName = exports.ruleName = (0, _utils.namespace)('broken');
var messages = exports.messages = _stylelint.utils.ruleMessages(ruleName, {
  broken: function broken(imageURL) {
    return `The image "${imageURL}" it's broken.`;
  }
});

exports.default = function (enabled) {
  return function (root, result) {
    var validOptions = _stylelint.utils.validateOptions(result, ruleName, {
      actual: enabled,
      possible: [true, false]
    });

    if (!validOptions) {
      return null;
    }

    var list = (0, _utils.generateAbsoluteNodesAndURLsList)(root);

    return checkIfImagesExists(list, result).then(function (results) {
      return reportBrokenImages(results, result);
    });
  };
};

function checkIfImagesExists(list) {
  var checkList = list.map(function (listItem) {
    return settlePromise(checkIfImageExists(listItem));
  });

  return Promise.all(checkList);
}

function settlePromise(promise) {
  return promise.catch(function (listItemError) {
    return listItemError;
  });
}

function checkIfImageExists(listItem) {
  return (0, _utils.getImage)(listItem.url).catch(function (error) {
    error.nodeAndURL = listItem;

    return Promise.reject(error);
  });
}

function reportBrokenImages(results, result) {
  results.filter(function (resultItem) {
    return resultItem instanceof Error;
  }).forEach(function (resultError) {
    var _resultError$nodeAndU = resultError.nodeAndURL,
        node = _resultError$nodeAndU.node,
        url = _resultError$nodeAndU.url;

    _stylelint.utils.report({ message: messages.broken(url), node, result, ruleName });
  });
}
//# sourceMappingURL=index.js.map