'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.namespace = namespace;
exports.generateAbsoluteNodesAndURLsList = generateAbsoluteNodesAndURLsList;
exports.getImage = getImage;

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var prefix = 'images';

function namespace(ruleName) {
  return `${prefix}/${ruleName}`;
}

function generateAbsoluteNodesAndURLsList(root) {
  // https://github.com/postcss/postcss-url/blob/a9d1d4307b061210b1e051d1c2e9c481ca6afbf5/index.js#L26-L29
  var URL_VALUE_PATTERNS = [/(url\(\s*['"]?)([^"')]+)(["']?\s*\))/g, /(AlphaImageLoader\(\s*src=['"]?)([^"')]+)(["'])/g];
  // https://github.com/bezoerb/postcss-image-inliner/blob/8b825acebace2f1567195b49e47c0d454de4a3ae/index.js#L69
  var URL_PROPERTY_PATTERN = /^(background(?:-image)?)|(content)|(cursor)/;
  // http://stackoverflow.com/a/19709846/4709891
  var ABSOLUTE_URL = /^(?:[a-z]+:)?\/\//i;
  var list = [];

  root.walkDecls(URL_PROPERTY_PATTERN, function (node) {
    var listItem = URL_VALUE_PATTERNS.filter(function (valuePattern) {
      return valuePattern.test(node.value);
    }).map(function (valuePattern) {
      var getURLs = node.value.replace(valuePattern, '$2');
      var splitURLs = getURLs.split(',').map(function (url) {
        return url.trim();
      });
      var URLsAndNodes = splitURLs.map(function (url) {
        return { url, node };
      });
      var absoluteURLsAndNodes = URLsAndNodes.filter(function (item) {
        return ABSOLUTE_URL.test(item.url);
      });
      return absoluteURLsAndNodes;
    });

    if (listItem && listItem[0]) {
      listItem[0].forEach(function (URLsAndNodes) {
        list.push(URLsAndNodes);
      });
    }
  });

  return list;
}

var cacheImageResults = new Map();

function getImage(url) {
  if (cacheImageResults.has(url)) {
    return preservePromiseMethods(cacheImageResults.get(url));
  }

  return _axios2.default.get(url).then(function (response) {
    cacheImageResults.set(url, response);
    return response;
  }).catch(function (error) {
    cacheImageResults.set(url, error);
    return error;
  }).then(preservePromiseMethods);
}

function preservePromiseMethods(result) {
  if (result instanceof Error) {
    return Promise.reject(result);
  }

  return Promise.resolve(result);
}
//# sourceMappingURL=index.js.map